#
# spec file for package python-happybase
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-happybase
Version:        0.9
Release:        4.2
Summary:        A developer-friendly Python library to interact with Apache HBase
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/wbolster/happybase
Source:         https://pypi.python.org/packages/source/h/happybase/happybase-%{version}.tar.gz
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-thrift
Requires:       python-thrift
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
HappyBase is a developer-friendly Python library to interact with Apache HBase.

%prep
%setup -q -n happybase-%{version}

%build
python setup.py build
python setup.py build_sphinx
# Remove hidden file generated by Sphinx
rm doc/build/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot} 

%check
python setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE.rst NEWS.rst README.rst TODO.rst doc/build/html
%{python_sitelib}/*

%changelog
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.9:
  * Fix an issue where scanners would return fewer results than
    expected due to HBase not always behaving as its documentation
    suggests (issue #72).
  * Add support for the Thrift compact protocol (TCompactProtocol)
    in :py:class:`Connection` (issue #70).
* Tue Apr 15 2014 dmueller@suse.com
- update to 0.8:
  * Add (and default to) '0.96' compatibility mode in :py:class:`Connection`.
  * Add support for retrieving sorted columns, which is possible with the HBase
  0.96 Thrift API
  * The `batch_size` argument to :py:meth:`Table.scan` is no longer propagated to
  `Scan.setBatching()` at the Java side (inside the Thrift server).
* Mon Dec  9 2013 p.drouand@gmail.com
- Update to version 0.7
  * Added a `wal` argument to various data manipulation methods on the
    :py:class:`Table` and :py:class:`Batch` classes to determine whether
    to write the mutation to the Write-Ahead Log (WAL). (`issue #36
    <https://github.com/wbolster/happybase/issues/36>`_).
  * Pass batch_size to underlying Thrift Scan instance (`issue #38
    <https://github.com/wbolster/happybase/issues/38>`_).
  * Expose server name and port in :py:meth:`Table.regions` (recent HBase
    versions only) (`issue #37
    <https://github.com/wbolster/happybase/issues/37>`_).
  * Regenerated bundled Thrift API modules using a recent upstream
    Thrift APIdefinition. This is required to expose newly added API.
- Package NEWS.rst, TODO.rst and html pages in documentation directory
- Add python-Sphinx requirement to build html documentation
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.6:
  * Rewrote exception handling in connection pool. Exception handling is now a lot
  cleaner and does not introduce cyclic references anymore. (`issue #25
  <https://github.com/wbolster/happybase/issues/25>`_).
  * Regenerated bundled Thrift code using Thrift 0.9.0 with the new-style classes
  flag (`issue #27 <https://github.com/wbolster/happybase/issues/27>`_).
* Mon Jun 10 2013 dmueller@suse.com
- update to 0.5:
  * Added a thread-safe connection pool (:py:class:`ConnectionPool`)
  * The :py:meth:`Connection.delete_table` method now features an optional
  `disable` parameter to make deleting enabled tables easier.
  * The debug log message emitted by :py:meth:`Table.scan` when closing a scanner
  * Increased Thrift dependency to at least 0.8.
  * The :py:class:`Connection` constructor now features an optional `timeout`
  parameter
  * The `timestamp` argument to various methods now also accepts `long` values
  * In some corner cases exceptions were raised during interpreter shutdown
* Fri Apr  5 2013 speilicke@suse.com
- Define python_sitelib to fix SLE_11_SP1 build
* Wed Mar 13 2013 speilicke@suse.com
- Install documetation
- Run testsuite
- Fix runtime dependencies, needs python-thrift
* Wed Mar 13 2013 dmueller@suse.com
- Initial packaging (0.4)
